==> order-center-domain-3.0.0-CLOUD-DEV-20220923.083913-71-sources.jar: com/tydic/dyc/oc/model/shiporder/UocShipOrderDo.java <==
package com.tydic.dyc.oc.model.shiporder;

import com.tydic.dyc.oc.model.order.sub.UocOrderAccessory;
import com.tydic.dyc.oc.model.shiporder.sub.UocShipOrderItem;
import com.tydic.dyc.oc.model.shiporder.sub.UocShipOrderMap;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrder
 * 说明:发货单
 * 时间:2022-02-21 14:31
 * 作者:罗有
 **/
@Data
public class UocShipOrderDo implements Serializable {
    private static final long serialVersionUID = 546206669473986270L;

    @DocField(value = "发货单id")
    private Long shipOrderId;

    @DocField(value = "允许变更时限")
    private Date allowChngTime;

    @DocField(value = "销售单id")
    private Long saleOrderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "发货单编码")
    private String shipOrderNo;

    @DocField(value = "外部发货单编码")
    private String shipOrderNoExt;

    @DocField(value = "发货单名称")
    private String shipOrderName;

    @DocField(value = "发货单类型")
    private Integer shipOrderType;

    @DocField(value = "发货单状态")
    private String shipOrderState;

    @DocField(value = "供应商编码")
    private String supNo;

    @DocField(value = "供应商账户")
    private String supAccount;

    @DocField(value = "物流公司id")
    private String shipCompanyId;

    @DocField(value = "物流公司名称")
    private String shipCompanyName;

    @DocField(value = "物流单号")
    private String shipCompanyNo;

    @DocField(value = "车牌号")
    private String carNo;

    @DocField(value = "运输方式")
    private Integer transportMode;

    @DocField(value = "运输方式翻译")
    private String transportModeStr;

    @DocField(value = "发货时间")
    private Date shipTime;

    @DocField(value = "发货联系人姓名")
    private String shipName;

    @DocField(value = "发货联系人电话")
    private String shipPhone;

    @DocField(value = "发货工号")
    private String shipOperId;

    @DocField(value = "预计到货时间")
    private Date estimateArrivalTime;

    @DocField(value = "到货时间")
    private Date arriveTime;

    @DocField(value = "验收时间-该发货单全部被验收")
    private Date inspTime;

    @DocField(value = "验收人名称")
    private String inspOperName;

    @DocField(value = "验收人工号")
    private String inspOperId;

    @DocField(value = "验收人电话")
    private String inspOperPhone;


    @DocField(value = "发货备注")
    private String shipRemark;

    @DocField(value = "到货备注")
    private String arriveRemark;

    @DocField(value = "收/拒收 货人")
    private String receiverUser;

    @DocField(value = "收/拒收 货备注")
    private String receiverRemark;

    @DocField(value = "收/拒收 联系人")
    private String receiverContact;

    @DocField(value = "收/拒收 时间")
    private Date receiverTime;

    @DocField(value = "是否可以异常变更：1：不允许；其他情况都可以")
    private Integer isAbnormal;

    @DocField(value = "环节编码")
    private String procState;

    @DocField(value = "竣工标志             1 竣工             0 在途")
    private Integer finishFlag;

    @DocField(value = "租户ID")
    private String tenantId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "撤单时间")
    private Date cancelTime;

    @DocField(value = "撤单工号")
    private String cancelOperId;

    @DocField(value = "撤单原因")
    private String cancelReason;

    @DocField(value = "撤单标志:1 已撤单             0 未撤单")
    private Integer cancelFlag;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "竣工时间")
    private Date finishTime;

    @DocField(value = "逾期时间")
    private Date expTime;

    @DocField(value = "发货单扩展")
    private List<UocShipOrderMap> extParallelBoList;

    @DocField(value = "发货单明细")
    private List<UocShipOrderItem> shipOrderItemBoList;

    @DocField(value = "附件")
    private List<UocOrderAccessory> orderAccessoryBoList;

    @DocField(value = "发货单IDList")
    private List<Long> shipOrderIdList;

    @DocField(value = "发货单明细IDList")
    private List<Long> shipOrderItemIdList;

    @DocField(value = "订单IDList")
    private List<Long> orderIdList;

    @DocField(value = "订单来源  1 自营单品   2 电商导入   3 协议生成    ")
    private Integer orderSource;

}

==> order-center-domain-3.1.0-CLOUD-DEV-20230626.005721-59-sources.jar: com/tydic/dyc/oc/model/shiporder/UocShipOrderDo.java <==
package com.tydic.dyc.oc.model.shiporder;

import com.tydic.dyc.oc.model.order.sub.UocOrderAccessory;
import com.tydic.dyc.oc.model.shiporder.sub.UocShipOrderItem;
import com.tydic.dyc.oc.model.shiporder.sub.UocShipOrderMap;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrder
 * 说明:发货单
 * 时间:2022-02-21 14:31
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocShipOrderDo implements Serializable {
    private static final long serialVersionUID = 546206669473986270L;

    @DocField(value = "发货单id")
    private Long shipOrderId;

    @DocField(value = "允许变更时限")
    private Date allowChngTime;

    @DocField(value = "销售单id")
    private Long saleOrderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "发货单编码")
    private String shipOrderNo;

    @DocField(value = "外部发货单编码")
    private String shipOrderNoExt;

    @DocField(value = "发货单名称")
    private String shipOrderName;

    @DocField(value = "发货单类型")
    private Integer shipOrderType;

    @DocField(value = "发货单状态")
    private String shipOrderState;

    @DocField(value = "供应商编码")
    private String supNo;

    @DocField(value = "供应商账户")
    private String supAccount;

    @DocField(value = "物流公司id")
    private String shipCompanyId;

    @DocField(value = "物流公司名称")
    private String shipCompanyName;

    @DocField(value = "物流单号")
    private String shipCompanyNo;

    @DocField(value = "车牌号")
    private String carNo;

    @DocField(value = "运输方式")
    private Integer transportMode;

    @DocField(value = "运输方式翻译")
    private String transportModeStr;

    @DocField(value = "发货时间")
    private Date shipTime;

    @DocField(value = "发货联系人姓名")
    private String shipName;

    @DocField(value = "发货联系人电话")
    private String shipPhone;

    @DocField(value = "发货工号")
    private String shipOperId;

    @DocField(value = "预计到货时间")
    private Date estimateArrivalTime;

    @DocField(value = "到货时间")
    private Date arriveTime;

    @DocField(value = "验收时间-该发货单全部被验收")
    private Date inspTime;

    @DocField(value = "验收人名称")
    private String inspOperName;

    @DocField(value = "验收人工号")
    private String inspOperId;

    @DocField(value = "验收人电话")
    private String inspOperPhone;


    @DocField(value = "发货备注")
    private String shipRemark;

    @DocField(value = "到货备注")
    private String arriveRemark;

    @DocField(value = "收/拒收 货人")
    private String receiverUser;

    @DocField(value = "收/拒收 货备注")
    private String receiverRemark;

    @DocField(value = "收/拒收 联系人")
    private String receiverContact;

    @DocField(value = "收/拒收 时间")
    private Date receiverTime;

    @DocField(value = "是否可以异常变更：1：不允许；其他情况都可以")
    private Integer isAbnormal;

    @DocField(value = "环节编码")
    private String procState;

    @DocField(value = "竣工标志             1 竣工             0 在途")
    private Integer finishFlag;

    @DocField(value = "租户ID")
    private String tenantId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "撤单时间")
    private Date cancelTime;

    @DocField(value = "撤单工号")
    private String cancelOperId;

    @DocField(value = "撤单原因")
    private String cancelReason;

    @DocField(value = "撤单标志:1 已撤单             0 未撤单")
    private Integer cancelFlag;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "竣工时间")
    private Date finishTime;

    @DocField(value = "逾期时间")
    private Date expTime;

    @DocField(value = "发货单扩展")
    private List<UocShipOrderMap> extParallelBoList;

    @DocField(value = "发货单明细")
    private List<UocShipOrderItem> shipOrderItemBoList;

    @DocField(value = "附件")
    private List<UocOrderAccessory> orderAccessoryBoList;

    @DocField(value = "发货单IDList")
    private List<Long> shipOrderIdList;

    @DocField(value = "发货单明细IDList")
    private List<Long> shipOrderItemIdList;

    @DocField(value = "订单IDList")
    private List<Long> orderIdList;

    @DocField(value = "订单来源  1 自营单品   2 电商导入   3 协议生成    ")
    private Integer orderSource;
    
    @DocField("到货时间开始")
    private Date arriveTimeStart;
    
    @DocField("到货时间结束")
    private Date arriveTimeEnd;
}
